@@ -9,8 +9,12 @@
 #ifdef __BEOS__
 #define DEFAULT_MEM_DEV "/dev/misc/mem"
 #else
+#ifdef __sun
+#define DEFAULT_MEM_DEV "/dev/xsvc"
+#else
 #define DEFAULT_MEM_DEV "/dev/mem"
 #endif
+#endif
 
 /* Use mmap or not */
 #ifndef __BEOS__
